@@ -12,15 +12,15 @@ def expired_contests():
 
     now = datetime.datetime.utcnow()
 
-    subq = select([func.count(Contest.entrants)]).where(
-        Contest.id==Entrant.contest_id
-    ).scalar_subquery()
+    #  subq = select(func.count(Contest.entrants)).where(
+    #    Contest.id == Entrant.contest_id).scalar_subquery()
 
-    contests = session.query(Contest).filter(
-        or_( Contest.expires < now, subq >= Contest.max_entrants )
-    ).all()
+    # contests = session.query(Contest).filter(
+    #    or_( Contest.expires < now, subq >= Contest.max_entrants )
+    # ).all()
 
-    if not contests:
+    contests = session.query(Contest).filter(Contest.expires < now).all()
+    if contests is None or len(contests) == 0:
         raise Exception("No contests that meet criteria")
 
     return contests
